==> grizzly-framework-2.2.16-sources.jar: org/glassfish/grizzly/CompletionHandler.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2008-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.grizzly;

/**
 * Interface, which will be used by Grizzly to notify about asynchronous I/O
 * operations status updates.
 * 
 * @author Alexey Stashok
 */
public interface CompletionHandler<E> {
    /**
     * The operation was cancelled.
     */
    void cancelled();

    /**
     * The operation was failed.
     * @param throwable error, which occurred during operation execution
     */
    void failed(Throwable throwable);

    /**
     * The operation was completed.
     * @param result the operation result
     */
    void completed(E result);

    /**
     * The callback method may be called, when there is some progress in
     * operation execution, but it is still not completed
     * @param result the current result
     */
    void updated(E result);
}

==> grizzly-framework-2.3.19-sources.jar: org/glassfish/grizzly/CompletionHandler.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2008-2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.grizzly;

/**
 * Interface, which will be used by Grizzly to notify about asynchronous I/O
 * operations status updates.
 * 
 * @param <E> the type of the result
 * 
 * @author Alexey Stashok
 */
public interface CompletionHandler<E> {
    /**
     * The operation was cancelled.
     */
    void cancelled();

    /**
     * The operation was failed.
     * @param throwable error, which occurred during operation execution
     */
    void failed(Throwable throwable);

    /**
     * The operation was completed.
     * @param result the operation result
     * 
     * Please note, for performance reasons the result object might be recycled
     * after returning from the completed method. So it's not guaranteed that
     * using of the result object is safe outside this method's scope.
     */
    void completed(E result);

    /**
     * The callback method may be called, when there is some progress in
     * operation execution, but it is still not completed
     * @param result the current result
     * 
     * Please note, for performance reasons the result object might be recycled
     * after returning from the updated method. So it's not guaranteed that
     * using of the result object is safe outside this method's scope.
     */
    void updated(E result);
}
